==> pyob-0.1.1.tar.gz: pyob-0.1.1/pyob/exceptions/__init__.py <==
# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ INVALID KEY ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class DuplicateKeyError(Exception):
    """ Duplicate Key Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ INVALID KEY ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class InvalidKeyError(Exception):
    """ Invalid Key Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ INVALID OBJECT ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class InvalidObjectError(Exception):
    """ Invalid Object Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ INVALID TYPE ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class InvalidTypeError(Exception):
    """ Invalid Type Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ MIXED OBJECTS ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class MixedObjectsError(Exception):
    """ Mxed Objects Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ MULTIPLE OBJECTS ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class MultipleObjectsError(Exception):
    """ Multiple Objects Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ UNICITY ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class UnicityError(Exception):
    """ Unicity Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ ZERO OBJECTS ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class ZeroObjectsError(Exception):
    """ Zero Objects Error """

==> pyob-0.2.2.tar.gz: pyob-0.2.2/pyob/exceptions/__init__.py <==
# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ INVALID KEY ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class DuplicateKeyError(Exception):
    """ Duplicate Key Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ INVALID KEY ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class InvalidKeyError(Exception):
    """ Invalid Key Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ INVALID OBJECT ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class InvalidObjectError(Exception):
    """ Invalid Object Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ INVALID TYPE ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class InvalidTypeError(Exception):
    """ Invalid Type Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ MULTIPLE OBJECTS ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class MultipleObjectsError(Exception):
    """ Multiple Objects Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ NON-EXISTENT KEY ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class NonExistentKeyError(Exception):
    """ Invalid Type Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ UNICITY ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class UnicityError(Exception):
    """ Unicity Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ UNRELATED OBJECTS ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class UnrelatedObjectsError(Exception):
    """ Unrelated Objects Error """


# ┌─────────────────────────────────────────────────────────────────────────────────────
# │ ZERO OBJECTS ERROR
# └─────────────────────────────────────────────────────────────────────────────────────


class ZeroObjectsError(Exception):
    """ Zero Objects Error """
